=========
Changelog
=========

Version 0.1.5
=============

- corrected author e-mail address

Version 0.1.4
=============

- updates for new s1_sigma version 1.0

Version 0.1.3
=============

- added metadata definition for flood products

Version 0.1.2
=============

- added metadata definition for harmonic parameter products

Version 0.1.1
=============

- added metadata definition for temporal aggregated products

Version 0.1.0
=============

- setup of first basic metadata class
- supports encoding and decoding of attributes
- support for SAR product metadata
